==> jc-1.4.0.tar.gz: javax/security/sasl/AuthenticationException.h <==
// public class javax.security.sasl.AuthenticationException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b55000deb1188178 javax_security_sasl_AuthenticationException
// @dep_class a6a0dc46b22541cb javax_security_sasl_SaslException

// header file dependencies
// @dep_header javax_security_sasl_SaslException

#include "javax/security/sasl/SaslException.h"

#ifndef _JC_javax_security_sasl_AuthenticationException_H_
#define _JC_javax_security_sasl_AuthenticationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_security_sasl_AuthenticationException$sub_refs	_jc_javax_security_sasl_AuthenticationException$sub_refs;
typedef struct _jc_javax_security_sasl_AuthenticationException$sub_nonrefs	_jc_javax_security_sasl_AuthenticationException$sub_nonrefs;
typedef struct _jc_javax_security_sasl_AuthenticationException$refs	_jc_javax_security_sasl_AuthenticationException$refs;
typedef struct _jc_javax_security_sasl_AuthenticationException$nonrefs	_jc_javax_security_sasl_AuthenticationException$nonrefs;
typedef struct _jc_javax_security_sasl_AuthenticationException$object	_jc_javax_security_sasl_AuthenticationException$object;

typedef const struct _jc_javax_security_sasl_AuthenticationException$vmethods	_jc_javax_security_sasl_AuthenticationException$vmethods;
typedef const struct _jc_javax_security_sasl_AuthenticationException$vtable	_jc_javax_security_sasl_AuthenticationException$vtable;
typedef const struct _jc_javax_security_sasl_AuthenticationException$vtype	_jc_javax_security_sasl_AuthenticationException$vtype;

// Constructors
extern void _jc_javax_security_sasl_AuthenticationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_sasl_AuthenticationException$object *);
extern void _jc_javax_security_sasl_AuthenticationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_sasl_AuthenticationException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_sasl_AuthenticationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_security_sasl_AuthenticationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_javax_security_sasl_AuthenticationException$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_AuthenticationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_security_sasl_SaslException$vmethods	javax_security_sasl_SaslException;
	_jc_javax_security_sasl_AuthenticationException$vmethods	javax_security_sasl_AuthenticationException;
};

// Vtype
struct _jc_javax_security_sasl_AuthenticationException$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_AuthenticationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthenticationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_AuthenticationException$refs {
    _jc_javax_security_sasl_AuthenticationException$sub_refs	javax_security_sasl_AuthenticationException;
    _jc_javax_security_sasl_SaslException$sub_refs	javax_security_sasl_SaslException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthenticationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_AuthenticationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_security_sasl_SaslException$sub_nonrefs	javax_security_sasl_SaslException;
    _jc_javax_security_sasl_AuthenticationException$sub_nonrefs	javax_security_sasl_AuthenticationException;
};

// Object instance structure
struct _jc_javax_security_sasl_AuthenticationException$object {
	_jc_javax_security_sasl_AuthenticationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_AuthenticationException$vtype	*vtype;
	_jc_javax_security_sasl_AuthenticationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_AuthenticationException$vtype _jc_javax_security_sasl_AuthenticationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_AuthenticationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_AuthenticationException$class_object;

#endif	/* _JC_javax_security_sasl_AuthenticationException_H_ */

==> jc-1.4.6.tar.gz: javax/security/sasl/AuthenticationException.h <==
// public class javax.security.sasl.AuthenticationException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b55000deb1188178 javax_security_sasl_AuthenticationException
// @dep_class a6a0dc46b22541cb javax_security_sasl_SaslException

// header file dependencies
// @dep_header javax_security_sasl_SaslException

#include "javax/security/sasl/SaslException.h"

#ifndef _JC_javax_security_sasl_AuthenticationException_H_
#define _JC_javax_security_sasl_AuthenticationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_security_sasl_AuthenticationException$sub_refs	_jc_javax_security_sasl_AuthenticationException$sub_refs;
typedef struct _jc_javax_security_sasl_AuthenticationException$sub_nonrefs	_jc_javax_security_sasl_AuthenticationException$sub_nonrefs;
typedef struct _jc_javax_security_sasl_AuthenticationException$refs	_jc_javax_security_sasl_AuthenticationException$refs;
typedef struct _jc_javax_security_sasl_AuthenticationException$nonrefs	_jc_javax_security_sasl_AuthenticationException$nonrefs;
typedef struct _jc_javax_security_sasl_AuthenticationException$object	_jc_javax_security_sasl_AuthenticationException$object;

typedef const struct _jc_javax_security_sasl_AuthenticationException$vmethods	_jc_javax_security_sasl_AuthenticationException$vmethods;
typedef const struct _jc_javax_security_sasl_AuthenticationException$vtable	_jc_javax_security_sasl_AuthenticationException$vtable;
typedef const struct _jc_javax_security_sasl_AuthenticationException$vtype	_jc_javax_security_sasl_AuthenticationException$vtype;

// Constructors
extern void _jc_javax_security_sasl_AuthenticationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_sasl_AuthenticationException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_AuthenticationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_sasl_AuthenticationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_sasl_AuthenticationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_javax_security_sasl_AuthenticationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_sasl_AuthenticationException$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_AuthenticationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_javax_security_sasl_SaslException$vmethods	javax_security_sasl_SaslException;
	_jc_javax_security_sasl_AuthenticationException$vmethods	javax_security_sasl_AuthenticationException;
};

// Vtype
struct _jc_javax_security_sasl_AuthenticationException$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_AuthenticationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthenticationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_AuthenticationException$refs {
    _jc_javax_security_sasl_AuthenticationException$sub_refs	javax_security_sasl_AuthenticationException;
    _jc_javax_security_sasl_SaslException$sub_refs	javax_security_sasl_SaslException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_AuthenticationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_AuthenticationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_javax_security_sasl_SaslException$sub_nonrefs	javax_security_sasl_SaslException;
    _jc_javax_security_sasl_AuthenticationException$sub_nonrefs	javax_security_sasl_AuthenticationException;
};

// Object instance structure
struct _jc_javax_security_sasl_AuthenticationException$object {
	_jc_javax_security_sasl_AuthenticationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_AuthenticationException$vtype	*vtype;
	_jc_javax_security_sasl_AuthenticationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_AuthenticationException$vtype _jc_javax_security_sasl_AuthenticationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_AuthenticationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_AuthenticationException$class_object;

#endif	/* _JC_javax_security_sasl_AuthenticationException_H_ */
